@@ -109,6 +109,11 @@ class SpectralTrace:
         xi_arr = self.table[self.meta['s_colname']]
         lam_arr = self.table[self.meta['wave_colname']]
 
+        wi0, wi1 = lam_arr.argmin(), lam_arr.argmax()
+        x_disp_length = np.diff([x_arr[wi0], x_arr[wi1]])
+        y_disp_length = np.diff([y_arr[wi0], y_arr[wi1]])
+        self.dispersion_axis = "x" if x_disp_length > y_disp_length else "y"
+
         self.wave_min = quantify(np.min(lam_arr), u.um).value
         self.wave_max = quantify(np.max(lam_arr), u.um).value
 
@@ -203,8 +208,11 @@ class SpectralTrace:
         #         - The dispersion direction is selected by the direction of the
         #           gradient of lam(x, y). This works if the lam-axis is well
         #           aligned with x or y. Needs to be tested for MICADO.
-        dlam_by_dx, dlam_by_dy = self.xy2lam.gradient()
-        if np.abs(dlam_by_dx(0, 0)) > np.abs(dlam_by_dy(0, 0)):
+
+
+        # dlam_by_dx, dlam_by_dy = self.xy2lam.gradient()
+        # if np.abs(dlam_by_dx(0, 0)) > np.abs(dlam_by_dy(0, 0)):
+        if self.dispersion_axis == "x":
             avg_dlam_per_pix = (wave_max - wave_min) / sub_naxis1
         else:
             avg_dlam_per_pix = (wave_max - wave_min) / sub_naxis2
@@ -259,6 +267,7 @@ class SpectralTrace:
         image = xilam.interp(xi_fpa, lam_fpa, grid=False) * ijmask
 
         # Scale to ph / s / pixel
+        dlam_by_dx, dlam_by_dy = self.xy2lam.gradient()
         dlam_per_pix = pixsize * np.sqrt(dlam_by_dx(ximg_fpa, yimg_fpa)**2 +
                                          dlam_by_dy(ximg_fpa, yimg_fpa)**2)
         image *= pixscale * dlam_per_pix        # [arcsec/pix] * [um/pix]
@@ -414,7 +423,6 @@ class SpectralTrace:
         return msg
 
 
-
 class XiLamImage():
     """
     Class to compute a rectified 2D spectrum
@@ -459,7 +467,8 @@ class XiLamImage():
             # overlaps with the wavelength range covered by the cube
             if lam0.min() < cube_lam.max() and lam0.max() > cube_lam.min():
                 plane = fov.cube.data[:, i, :].T
-                plane_interp = RectBivariateSpline(cube_xi, cube_lam, plane)
+                plane_interp = RectBivariateSpline(cube_xi, cube_lam, plane,
+                                                   kx=1, ky=1)
                 self.image += plane_interp(cube_xi, lam0)
 
         self.image *= d_eta     # ph/s/um/arcsec2 --> ph/s/um/arcsec
